@@ -85,6 +85,8 @@ class OptionDescriptor(object):
 PLUGINS = [import_object(path)() for path in settings.TEST_PLUGINS]
 
 command_line_options = [
+  OptionDescriptor("-s", "--noselenium", dest = "no_selenium", action = "store_true"),
+  OptionDescriptor("-l", "--long", dest = "run_long_tests", action = "store_true"),
   OptionDescriptor("-g", "--grep", dest = "grep", action = "append"),
   OptionDescriptor("-t", "--tag", dest = "tag", action = "store"),
   OptionDescriptor("-m", "--max-tries", dest = "max_tries", action = "store", 
@@ -147,6 +149,11 @@ class NoSeleniumFilter(Filter):
     return not getattr(klass, 'selenium_test', False)
 
 
+class NoLongTestsFilter(Filter):
+  def test_method(self, klass, method):
+    return not getattr(method, "long_test", False)
+
+
 def get_method_path(klass, method):
   if hasattr(method, "__name__"):
     method = method.__name__
@@ -161,8 +168,7 @@ class TestDriver(object):
                num_workers = None, 
                worker_num = None,
                max_tries = 1,
-               never_debug = False,
-               run_selenium_tests = True):
+               never_debug = False):
     self.test_paths = test_paths
     self.num_workers = num_workers \
                        if num_workers != None \
@@ -186,8 +192,6 @@ class TestDriver(object):
     self.methods = []
 
     self.filters = []  # List of Filter objects
-    if not run_selenium_tests:
-      self.filters.append(NoSeleniumFilter())
 
 
   def add_path(self, path):
@@ -269,15 +273,10 @@ class TestDriver(object):
     if self.filters and any((not p.test_method(klass, method) for p in self.filters)):
       return
 
-    if getattr(method, "long_test", False) and not getattr(settings, "RUN_LONG_TESTS", "True"):
-      print "Skipping test %s as it's long and we're not running long tests."
-      return
-
-
-    print "-" * 50
-    print "%s (Worker %s/%s)" % \
+    print >>sys.stderr, "-" * 50
+    print >>sys.stderr, "%s (Worker %s/%s)" % \
           (method_path, self.worker_num, self.num_workers)
-    print "-" * 50
+    print >>sys.stderr, "-" * 50
 
     try_num = 1
     finished = False
@@ -288,7 +287,12 @@ class TestDriver(object):
     while not finished and try_num <= self.max_tries:
       try:
         # Actually run the test
-        if getattr(method, "has_variations", False):
+        if getattr(method, "is_operation_test", False):
+          for_all_plugins("start_running_test_try", self, klass, method_name)
+          method()
+          for_all_plugins("finish_running_test_try", self, klass, method_name)
+          torn_down = True
+        elif getattr(method, "has_variations", False):
           for_all_plugins("start_running_test_try", self, klass, method_name)
           MyVariationRunner().run_test(method)
           for_all_plugins("finish_running_test_try", self, klass, method_name)
@@ -311,7 +315,6 @@ class TestDriver(object):
         for_all_plugins("finish_running_test_try", self, klass, method_name)
 
         if try_num == self.max_tries:
-          print "FAILED: ", e
           etype, value, tb = sys.exc_info()
           
           st = traceback.format_tb(tb)
@@ -394,6 +397,11 @@ class CustomTestRunner(object):
 
     driver.never_debug = options["never_debug"]
 
+    if not test_paths and not options["grep"] and not options["run_long_tests"]:
+      driver.filters.append(NoLongTestsFilter())
+    if options['no_selenium']:
+      driver.filters.append(NoSeleniumFilter())
+
     if test_paths:
       for p in test_paths:
         driver.add_path(p)
@@ -413,6 +421,7 @@ class CustomTestRunner(object):
           break
       if add_all_tests:
         driver.add_all_tests()
+
       
     driver.run()
 
@@ -510,9 +519,18 @@ class TestCase(object):
 
   def teardown_database(self, transactions = True):
     if not transactions:
-      restore_transaction_methods()
-      transaction.rollback()
-      transaction.leave_transaction_management()
+      try:
+        restore_transaction_methods()
+      except:
+        pass
+      try:
+        transaction.rollback()
+      except:
+        pass
+      try:
+        transaction.leave_transaction_management()
+      except:
+        pass
 
 
   def _test_setup(self):
