@@ -1,5 +1,5 @@
 import re
-import simplejson
+from django.utils import simplejson
 from time import sleep
 from django.core.handlers.wsgi import WSGIHandler
 from django.core.servers.basehttp import AdminMediaHandler
@@ -9,6 +9,9 @@ from django.conf import settings
 from selenium_python import selenium #TODO
 from sxml.parser import expression as jquery_expression
 
+import socket
+import logging
+
 from django_test import TestCase
 from django_test.utils import restore_database
 
@@ -76,7 +79,11 @@ class ConvenientSelenium(NewStyleSelenium):
 
   def _wait_if_asked(self, locator, wait):
     if wait:
-      self.wait_for_condition("""env.$("%s").length > 0""" % locator)
+      self.wait_for_condition("""env.$ != null && env.$("%s").length > 0""" % locator)
+
+  def get_text(self, locator, wait = False):
+    self._wait_if_asked(locator, wait)
+    return super(ConvenientSelenium, self).get_text(self.resolve_locator(locator))
 
   def click(self, locator, wait = False):
     """
@@ -153,6 +160,9 @@ class ConvenientSelenium(NewStyleSelenium):
     self._wait_if_asked(locator, wait)
     return super(ConvenientSelenium, self).get_selected_value(self.resolve_locator(locator))
 
+  def get_value(self, locator, wait = False):
+    self._wait_if_asked(locator, wait)
+    return super(ConvenientSelenium, self).get_value(self.resolve_locator(locator))
 
   def drag_and_drop_to_object(self, locator_from, locator_to, wait = False):
     self._wait_if_asked(locator_from, wait)
@@ -209,7 +219,6 @@ class SeleniumTestCase(TestCase):
     # Start the selenium client if it's not started yet
     if not hasattr(SeleniumTestCase, "selenium"):
       selenium_port = getattr(settings, "SELENIUM_PORT", 4444) 
-
       SeleniumTestCase.selenium = ConvenientSelenium(
        "localhost", 
        selenium_port,
@@ -248,10 +257,15 @@ class SeleniumTestCase(TestCase):
 
 
   def tearDown(self):
-    self.teardown_database(transactions = True)
     # Tim is awesome for helping with this bit.
-    self.server.httpd.requests.stop(0) # shutdown timeout?  pfft.
-    self.stopped = True
+    try:
+      print "shutting down cherrypy"
+      #self.server.httpd.requests.stop(0) # shutdown timeout?  pfft.
+      print "shut down cherrypy"
+    except socket.error:
+      logging.info("Socket error stopping CherryPy requests")
+    self.teardown_database(transactions = True)
+    #self.stopped = True
 
 
   def _test_setup(self):
